==> haskell-hyphenation-0.8.2-159-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hyphenation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hyphenation
version:              0.8.2
visibility:           public
id:                   hyphenation-0.8.2-Eypn1Jkc3Hf9bixCIMTKe4
key:                  hyphenation-0.8.2-Eypn1Jkc3Hf9bixCIMTKe4
license:              BSD-2-Clause
copyright:            (C) 2012-2019 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/hyphenation
synopsis:             Configurable Knuth-Liang hyphenation
description:
    Configurable Knuth-Liang hyphenation

    Uses the UTF8 encoded hyphenation patterns provided by
    hyph-utf8 from
    <http://www.ctan.org/tex-archive/language/hyph-utf8>

    Usage:

    >>> hyphenate english_US "supercalifragilisticexpialadocious"
    ["su","per","cal","ifrag","ilis","tic","ex","pi","al","ado","cious"]

    >>> hyphenate english_US "hyphenation"
    ["hy","phen","ation"]

    >>> hyphenate icelandic "va\240lahei\240avegavinnuverkf\230rageymslusk\250r"
    ["va\240la","hei\240a","vega","vinnu","verk","f\230ra","geymslu","sk\250r"]

category:             Text
abi:                  8d1a3ab6d500d000b643952c8c511e25
exposed:              True
exposed-modules:
    Text.Hyphenation Text.Hyphenation.Exception
    Text.Hyphenation.Hyphenator Text.Hyphenation.Language
    Text.Hyphenation.Pattern

hidden-modules:
    Text.Hyphenation.ByteStringLazyCompat Paths_hyphenation

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hyphenation-0.8.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hyphenation-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hyphenation
hs-libraries:         HShyphenation-0.8.2-Eypn1Jkc3Hf9bixCIMTKe4
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND text-1.2.5.0
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ
    zlib-0.6.3.0-7eb8DNb2CEF4EgehmrZW7c

haddock-interfaces:   /usr/share/doc/haskell-hyphenation/html/hyphenation.haddock
haddock-html:         /usr/share/doc/haskell-hyphenation/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hyphenation-0.8.3-25.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hyphenation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hyphenation
version:              0.8.3
visibility:           public
id:                   hyphenation-0.8.3-AygoEuCD2SCXOJh65M9zw
key:                  hyphenation-0.8.3-AygoEuCD2SCXOJh65M9zw
license:              BSD-2-Clause
copyright:            (C) 2012-2019 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/hyphenation
synopsis:             Configurable Knuth-Liang hyphenation
description:
    Configurable Knuth-Liang hyphenation

    Uses the UTF8 encoded hyphenation patterns provided by
    hyph-utf8 from
    <http://www.ctan.org/tex-archive/language/hyph-utf8>

    Usage:

    >>> hyphenate english_US "supercalifragilisticexpialadocious"
    ["su","per","cal","ifrag","ilis","tic","ex","pi","al","ado","cious"]

    >>> hyphenate english_US "hyphenation"
    ["hy","phen","ation"]

    >>> hyphenate icelandic "va\240lahei\240avegavinnuverkf\230rageymslusk\250r"
    ["va\240la","hei\240a","vega","vinnu","verk","f\230ra","geymslu","sk\250r"]

category:             Text
abi:                  ae58e5dd4ff10c262d8e96fad4228b54
exposed:              True
exposed-modules:
    Text.Hyphenation Text.Hyphenation.Exception
    Text.Hyphenation.Hyphenator Text.Hyphenation.Language
    Text.Hyphenation.Pattern

hidden-modules:       Paths_hyphenation
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hyphenation-0.8.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hyphenation-0.8.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hyphenation-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hyphenation
hs-libraries:         HShyphenation-0.8.3-AygoEuCD2SCXOJh65M9zw
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    file-embed-0.0.15.0-7OnjuFj6gBM9fqBKJCVXdU text-2.0.2
    unordered-containers-0.2.20-WenrpHtwHKIVom5hXYF7C
    zlib-0.6.3.0-97FgXTqrChC25IpT7zWdnE

haddock-interfaces:   /usr/share/doc/haskell-hyphenation/html/hyphenation.haddock
haddock-html:         /usr/share/doc/haskell-hyphenation/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
